pub enum DebError {
Mkdir(PathBuf, Error),
Mkdir2(PathBuf, UtilError),
Apt(AptRepoError),
UrlParse(String, ParseError),
HttpGet(Url, PathBuf, UtilError),
}Expand description
Errors from the deb action.
Variants
Mkdir(PathBuf, Error)
Failed to create the artifacts directory for deb packages.
Mkdir2(PathBuf, UtilError)
Failed to create the artifacts directory for deb packages.
Apt(AptRepoError)
APT repository error.
UrlParse(String, ParseError)
Parse URL.
HttpGet(Url, PathBuf, UtilError)
Download file