pub struct Custom {
pub name: String,
pub args: HashMap<String, Value>,
}Expand description
Execute a custom action.
Run the named executable from .ambient at the root of the source
tree. The arguments in args are used to set environment variables
and are also passed in via the standard input, both as JSON. Note that
there is no way for Ambient to check that the necessary arguments are
provided.
An args value of foo results in AMBIENT_CI_foo being set in the
environment.
Fields
name: StringName of custom action executable in .ambient.
args: HashMap<String, Value>Arguments to custom action.
Implementations