pub struct Dput { /* private fields */ }Expand description
Upload a built deb package using the dput command.
The host must have dput configured to support the specified upload
target.
Implementations