pub struct Mkdir { /* private fields */ }Expand description
Create a directory.
This is meant for internal use by Ambient. It can’t be used in any kind of plan, pre-plan, or post-plan. It can be used in a runnable plan. It is generated by Ambient to set up execution of a runnable plan.
Implementations