pub struct Shell { /* private fields */ }Expand description
Execute a snippet of shell script.
The snippet is executed using bash, with set -xeuo pipefail to make
it fail if any command fails, or an unset variable is used, and to trace
execution to allow easier debugging.
Implementations