pub struct Project {
pub source: TildePathBuf,
pub image: TildePathBuf,
pub pre_plan: Option<Vec<PrePlanAction>>,
pub plan: Option<Vec<UnsafeAction>>,
pub post_plan: Option<Vec<PostPlanAction>>,
pub artifact_max_size: Option<u64>,
pub cache_max_size: Option<u64>,
/* private fields */
}Expand description
Specification of one CI project.
Fields
source: TildePathBufSource directory.
image: TildePathBufVirtual machine image to use.
pre_plan: Option<Vec<PrePlanAction>>Pre-plan actions.
plan: Option<Vec<UnsafeAction>>Plan actions.
post_plan: Option<Vec<PostPlanAction>>Post-plan actions.
artifact_max_size: Option<u64>Maximum size of artifacts directory for this project, in bytes.
cache_max_size: Option<u64>Maximum size of cache directory for this project, in bytes.
Implementations
Sourceimpl Project
impl Project
Sourcepub fn from_file(filename: &Path) -> Result<Self, ProjectError>
pub fn from_file(filename: &Path) -> Result<Self, ProjectError>
Load from file.
Sourcepub fn artifact_max_size(&self) -> Option<u64>
pub fn artifact_max_size(&self) -> Option<u64>
Maximum size of artifacts directory, in bytes.
Sourcepub fn cache_max_size(&self) -> Option<u64>
pub fn cache_max_size(&self) -> Option<u64>
Maximum size of cache directory, in bytes.
Sourcepub fn pre_plan(&self) -> &[PrePlanAction]
pub fn pre_plan(&self) -> &[PrePlanAction]
List of pre-plan actions.
Sourcepub fn plan(&self) -> &[UnsafeAction]
pub fn plan(&self) -> &[UnsafeAction]
List of plan actions.
Sourcepub fn post_plan(&self) -> &[PostPlanAction]
pub fn post_plan(&self) -> &[PostPlanAction]
List of post-plan actions.