Shell

Struct Shell 

pub struct Shell { /* private fields */ }
Execute a snippet of shell script.

The snippet is executed using bash, with set -xeuo pipefail to make it fail if any command fails, or an unset variable is used, and to trace execution to allow easier debugging.

Implementations

Source

impl Shell

pub fn new<S: Into<String>>(shell: S) -> Self

Create a new Shell action.

pub fn shell(&self) -> &str

Shell snippet to run.